@@ -1,4 +1,4 @@
-# Copyright (C) 2003, 2004, 2006  Free Software Foundation, Inc.
+# Copyright (C) 2003  Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,8 +12,8 @@
 
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+# 02111-1307, USA.
 
 package Automake::Rule;
 use strict;
@@ -95,7 +95,7 @@ non-object).
 =cut
 
 my $_SUFFIX_RULE_PATTERN =
-  '^(\.[a-zA-Z0-9_(){}$+@\-]+)(\.[a-zA-Z0-9_(){}$+@\-]+)' . "\$";
+  '^(\.[a-zA-Z0-9_(){}$+@]+)(\.[a-zA-Z0-9_(){}$+@]+)' . "\$";
 
 # Suffixes found during a run.
 use vars '@_suffixes';
@@ -328,16 +328,9 @@ sub reset()
      'install-man'	    => [],
      'uninstall-man'	    => [],
 
-     'install-dvi'          => [],
-     'install-dvi-am'       => [],
-     'install-html'         => [],
-     'install-html-am'      => [],
      'install-info'         => [],
      'install-info-am'      => [],
-     'install-pdf'          => [],
-     'install-pdf-am'       => [],
-     'install-ps'           => [],
-     'install-ps-am'        => [],
+     'uninstall-info'       => [],
 
      'installcheck-am'      => [],
 
@@ -356,8 +349,6 @@ sub reset()
 
      # Phoning.
      '.PHONY'               => [],
-     # Recursive install targets (so `make -n install' works for BSD Make).
-     '.MAKE'		    => [],
      );
   %actions = ();
 }
@@ -590,6 +581,9 @@ sub define ($$$$$)
       && $tdef
       && $noexerule->name ne $target)
     {
+      print "1. $noexe\n";
+      print "2. $target\n";
+      print "3. " . $noexerule->name . "\n";
       # The no-exeext option enables this feature.
       if (! option 'no-exeext')
 	{
@@ -631,7 +625,7 @@ sub define ($$$$$)
 	      if ($target !~ /^[^%]*%[^%]*$/)
 		{
 		  ## FIXME: Presently we can't diagnose duplicate user rules
-		  ## because we don't distinguish rules with commands
+		  ## because we doesn't distinguish rules with commands
 		  ## from rules that only add dependencies.  E.g.,
 		  ##   .PHONY: foo
 		  ##   .PHONY: bar
@@ -669,7 +663,7 @@ sub define ($$$$$)
 	      $noam =~ s/-am$//;
 	      if (exists $dependencies{"$noam-am"})
 		{
-		  $hint = "consider using $noam-local instead of $target";
+		  $hint = "consider using $target-local instead of $target";
 		}
 
 	      msg_cond_rule ('override', $cond, $target,
