@@ -1,8 +1,8 @@
-# Copyright (C) 2003, 2004, 2006  Free Software Foundation, Inc.
+# Copyright (C) 2003  Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
+# the Free Software Foundation; either version 2, or (at your option)
 # any later version.
 
 # This program is distributed in the hope that it will be useful,
@@ -11,7 +11,9 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+# 02111-1307, USA.
 
 package Automake::VarDef;
 use strict;
@@ -36,20 +38,17 @@ Automake::VarDef - a class for variable definitions
 
   # Create a VarDef for a definition such as
   # | # any comment
-  # | foo = bar # more comment
+  # | foo = bar
   # in Makefile.am
   my $loc = new Automake::Location 'Makefile.am:2';
-  my $def = new Automake::VarDef ('foo', 'bar # more comment',
-                                  '# any comment',
+  my $def = new Automake::VarDef ('foo', 'bar', '# any comment',
                                   $loc, '', VAR_MAKEFILE, VAR_ASIS);
 
   # Appending to a definition.
   $def->append ('value to append', 'comment to append');
 
   # Accessors.
-  my $value    = $def->value;  # with trailing `#' comments and
-                               # continuation ("\\\n") omitted.
-  my $value    = $def->raw_value; # the real value, as passed to new().
+  my $value    = $def->value;
   my $comment  = $def->comment;
   my $location = $def->location;
   my $type     = $def->type;
@@ -69,7 +68,7 @@ Automake::VarDef - a class for variable definitions
 
 =head1 DESCRIPTION
 
-This class gathers data related to one Makefile-variable definition.
+This class gather data related to one Makefile-variable definition.
 
 =head2 Constants
 
@@ -98,7 +97,7 @@ C<VAR_SORTED> variables should be sorted and then handled as
 C<VAR_PRETTY> variables.
 
 C<VAR_SILENT> variables can also be overridden silently (unlike the
-other kinds of variables whose overriding may sometimes produce
+other kinds of variables whose overridding may sometimes produce
 warnings).
 
 =cut
@@ -128,7 +127,7 @@ C<$comment> is any comment preceding the definition.  (Because
 Automake reorders variable definitions in the output, it also tries to
 carry comments around.)
 
-C<$location> is the place where the definition occurred, it should be
+C<$location> is the place where the definition occured, it should be
 an instance of L<Automake::Location>.
 
 C<$type> should be C<''> for definitions made with C<=>, and C<':'>
@@ -165,7 +164,7 @@ sub new ($$$$$$$$)
 
 =item C<$def-E<gt>append ($value, $comment)>
 
-Append C<$value> and <$comment> to the existing value and comment of
+Append C<$value> and <$comment> to the exisiting value and comment of
 C<$def>.  This is normally called on C<+=> definitions.
 
 =cut
@@ -176,16 +175,6 @@ sub append ($$$)
   $self->{'comment'} .= $comment;
 
   my $val = $self->{'value'};
-
-  # Strip comments from augmented variables.  This is so that
-  #   VAR = foo # com
-  #   VAR += bar
-  # does not become
-  #   VAR = foo # com bar
-  # Furthermore keeping `#' would not be portable if the variable is
-  # output on multiple lines.
-  $val =~ s/ ?#.*//;
-
   if (chomp $val)
     {
       # Insert a backslash before a trailing newline.
@@ -197,9 +186,6 @@ sub append ($$$)
       $val .= ' ';
     }
   $self->{'value'} = $val . $value;
-  # Turn ASIS appended variables into PRETTY variables.  This is to
-  # cope with `make' implementation that cannot read very long lines.
-  $self->{'pretty'} = VAR_PRETTY if $self->{'pretty'} == VAR_ASIS;
 }
 
 =item C<$def-E<gt>value>
@@ -214,18 +200,6 @@ documentation of C<new>'s arguments for a description of these.
 =cut
 
 sub value ($)
-{
-  my ($self) = @_;
-  my $val = $self->raw_value;
-  # Strip anything past `#'.  `#' characters cannot be escaped
-  # in Makefiles, so we don't have to be smart.
-  $val =~ s/#.*$//s;
-  # Strip backslashes.
-  $val =~ s/\\$/ /mg;
-  return $val;
-}
-
-sub raw_value ($)
 {
   my ($self) = @_;
   return $self->{'value'};
@@ -315,7 +289,7 @@ sub dump ($)
 
   my $where = $self->location->dump;
   my $comment = $self->comment;
-  my $value = $self->raw_value;
+  my $value = $self->value;
   my $type = $self->type;
 
   return "{
